==> ideaIC-182.4323.18-sources.jar: com/intellij/refactoring/ui/VisibilityPanelBase.java <==
/*
 * Copyright 2000-2010 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.refactoring.ui;

import com.intellij.util.EventDispatcher;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

@SuppressWarnings("deprecation")
public abstract class VisibilityPanelBase<V> extends JPanel {

  /**
   * @deprecated To be removed in 2018.2. Actually replaced by 'private'.
   * Use {@link #stateChanged(ChangeEvent)} instead. This field will become private.
   */
  protected final EventDispatcher<ChangeListener> myEventDispatcher = EventDispatcher.create(ChangeListener.class);

  @Nullable
  public abstract V getVisibility();

  public abstract void setVisibility(V visibility);

  public void addListener(ChangeListener listener) {
    myEventDispatcher.addListener(listener);
  }

  protected void stateChanged(ChangeEvent e) {
    myEventDispatcher.getMulticaster().stateChanged(e);
  }
}

==> ideaIC-2018.3.3-sources.jar: com/intellij/refactoring/ui/VisibilityPanelBase.java <==
/*
 * Copyright 2000-2010 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.refactoring.ui;

import com.intellij.util.EventDispatcher;
import org.jetbrains.annotations.Nullable;

import javax.swing.*;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

public abstract class VisibilityPanelBase<V> extends JPanel {

  /**
   * @deprecated To be removed in 2018.2. Actually replaced by 'private'.
   * Use {@link #stateChanged(ChangeEvent)} instead. This field will become private.
   */
  @Deprecated protected final EventDispatcher<ChangeListener> myEventDispatcher = EventDispatcher.create(ChangeListener.class);

  @Nullable
  public abstract V getVisibility();

  public abstract void setVisibility(V visibility);

  public void addListener(ChangeListener listener) {
    //noinspection deprecation
    myEventDispatcher.addListener(listener);
  }

  protected void stateChanged(ChangeEvent e) {
    //noinspection deprecation
    myEventDispatcher.getMulticaster().stateChanged(e);
  }
}
